Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.cpp	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.cpp	(revision 92413)
@@ -1819,6 +1819,8 @@
 int UICommon::openMediumSelectorDialog(QWidget *pParent, UIMediumDeviceType  enmMediumType, const QUuid &uCurrentMediumId,
                                        QUuid &uSelectedMediumUuid, const QString &strMachineFolder, const QString &strMachineName,
-                                       const QString &strMachineGuestOSTypeId, bool fEnableCreate, const QUuid &uMachineID)
-{
+                                       const QString &strMachineGuestOSTypeId, bool fEnableCreate, const QUuid &uMachineID,
+                                       UIActionPool *pActionPool)
+{
+    Q_UNUSED(pActionPool);
     QUuid uMachineOrGlobalId = uMachineID == QUuid() ? gEDataManager->GlobalID : uMachineID;
 
@@ -2093,5 +2095,6 @@
                                                                  uCurrentID, uMediumID,
                                                                  strMachineFolder, comConstMachine.GetName(),
-                                                                 comConstMachine.GetOSTypeId(), true /*fEnableCreate */, comConstMachine.GetId());
+                                                                 comConstMachine.GetOSTypeId(), true /*fEnableCreate */,
+                                                                 comConstMachine.GetId(), pActionPool);
                     if (iDialogReturn == UIMediumSelector::ReturnCode_LeftEmpty &&
                         (target.mediumType == UIMediumDeviceType_DVD || target.mediumType == UIMediumDeviceType_Floppy))
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.h	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.h	(revision 92413)
@@ -417,9 +417,11 @@
           * @param  fEnableCreate            Passes whether to show/enable create action in the medium selector dialog,
           * @param  uMachineID               Passes the machine UUID,
+          * @param  pActionPool              Passes the action pool instance pointer,
           * returns the return code of the UIMediumSelector::ReturnCode as int. In case of a medium selection
           *         UUID of the selected medium is stored in @param inOutUuid.*/
-        int openMediumSelectorDialog(QWidget *pParent, UIMediumDeviceType  enmMediumType, const QUuid &uCurrentMediumId, QUuid &uSelectedMediumUuid,
-                                     const QString &strMachineFolder, const QString &strMachineName,
-                                     const QString &strMachineGuestOSTypeId, bool fEnableCreate, const QUuid &uMachineID);
+        int openMediumSelectorDialog(QWidget *pParent, UIMediumDeviceType  enmMediumType, const QUuid &uCurrentMediumId,
+                                     QUuid &uSelectedMediumUuid, const QString &strMachineFolder, const QString &strMachineName,
+                                     const QString &strMachineGuestOSTypeId, bool fEnableCreate, const QUuid &uMachineID,
+                                     UIActionPool *pActionPool);
 
         /** Creates and shows a dialog (wizard) to create a medium of type @a enmMediumType.
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManager.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManager.cpp	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManager.cpp	(revision 92413)
@@ -973,5 +973,6 @@
         /* Use the "safe way" to open stack of Mac OS X Sheets: */
         QWidget *pWizardParent = windowManager().realParentWindow(this);
-        UISafePointerWizardNewVM pWizard = new UIWizardNewVM(pWizardParent, m_pWidget->fullGroupName(), "gui-createvm");
+        UISafePointerWizardNewVM pWizard = new UIWizardNewVM(pWizardParent, actionPool(),
+                                                             m_pWidget->fullGroupName(), "gui-createvm");
         windowManager().registerNewParent(pWizard, pWizardParent);
 
@@ -1099,5 +1100,5 @@
             UISafePointerSettingsDialogMachine pDialog = new UISettingsDialogMachine(pDialogParent,
                                                                                      uID.isNull() ? pItem->id() : uID,
-                                                                                     strCategory, strControl);
+                                                                                     strCategory, strControl, actionPool());
             windowManager().registerNewParent(pDialog, pDialogParent);
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp	(revision 92413)
@@ -2153,5 +2153,5 @@
     QPointer<UISettingsDialogMachine> pDialog = new UISettingsDialogMachine(activeMachineWindow(),
                                                                             machine().GetId(),
-                                                                            strCategory, strControl);
+                                                                            strCategory, strControl, actionPool());
     /* Executing VM settings window.
      * This blocking function calls for the internal event-loop to process all further events,
Index: /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp	(revision 92413)
@@ -320,9 +320,10 @@
 
 UISettingsDialogMachine::UISettingsDialogMachine(QWidget *pParent, const QUuid &uMachineId,
-                                                 const QString &strCategory, const QString &strControl)
+                                                 const QString &strCategory, const QString &strControl, UIActionPool *pActionPool)
     : UISettingsDialog(pParent)
     , m_uMachineId(uMachineId)
     , m_strCategory(strCategory)
     , m_strControl(strControl)
+    , m_pActionPool(pActionPool)
 {
     /* Prepare: */
@@ -705,5 +706,5 @@
                 case MachineSettingsPageType_Storage:
                 {
-                    pSettingsPage = new UIMachineSettingsStorage;
+                    pSettingsPage = new UIMachineSettingsStorage(m_pActionPool);
                     addItem(":/hd_32px.png", ":/hd_24px.png", ":/hd_16px.png",
                             iPageIndex, "#storage", pSettingsPage);
Index: /trunk/src/VBox/Frontends/VirtualBox/src/settings/machine/UIMachineSettingsStorage.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/settings/machine/UIMachineSettingsStorage.cpp	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/settings/machine/UIMachineSettingsStorage.cpp	(revision 92413)
@@ -2943,5 +2943,5 @@
 const QString UIMachineSettingsStorage::s_strAttachmentMimeType = QString("application/virtualbox;value=StorageAttachmentID");
 
-UIMachineSettingsStorage::UIMachineSettingsStorage()
+UIMachineSettingsStorage::UIMachineSettingsStorage(UIActionPool *pActionPool)
     : m_pModelStorage(0)
     , m_pMediumIdHolder(new UIMediumIDHolder(this))
@@ -3000,4 +3000,5 @@
     , m_pLabelEncryption(0)
     , m_pFieldEncryption(0)
+    , m_pActionPool(pActionPool)
 {
     /* Prepare: */
@@ -4010,5 +4011,5 @@
                                                       strMachineFolder, m_strMachineName,
                                                       m_strMachineGuestOSTypeId,
-                                                      true /* enable create action: */, m_uMachineId);
+                                                      true /* enable create action: */, m_uMachineId, m_pActionPool);
 
     if (iResult == UIMediumSelector::ReturnCode_Rejected ||
@@ -5223,5 +5224,5 @@
                                                       strMachineFolder, m_strMachineName,
                                                       m_strMachineGuestOSTypeId,
-                                                      true /* enable cr1eate action: */, m_uMachineId);
+                                                      true /* enable cr1eate action: */, m_uMachineId, m_pActionPool);
 
     /* Continue only if iResult is either UIMediumSelector::ReturnCode_Accepted or UIMediumSelector::ReturnCode_LeftEmpty: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/settings/machine/UIMachineSettingsStorage.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/settings/machine/UIMachineSettingsStorage.h	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/settings/machine/UIMachineSettingsStorage.h	(revision 92413)
@@ -42,6 +42,7 @@
 class QITreeView;
 class StorageModel;
+class QIToolBar;
+class UIActionPool;
 class UIMediumIDHolder;
-class QIToolBar;
 struct UIDataSettingsMachineStorage;
 struct UIDataSettingsMachineStorageController;
@@ -69,5 +70,5 @@
 
     /** Constructs Storage settings page. */
-    UIMachineSettingsStorage();
+    UIMachineSettingsStorage(UIActionPool *pActionPool);
     /** Destructs Storage settings page. */
     virtual ~UIMachineSettingsStorage() /* override */;
@@ -407,4 +408,6 @@
         /** Holds the encryption field instance. */
         QILabel          *m_pFieldEncryption;
+        /** Holds the action pool instance. */
+        UIActionPool     *m_pActionPool;
    /** @} */
 };
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.cpp	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.cpp	(revision 92413)
@@ -52,5 +52,6 @@
 }
 
-UIWizardNewVM::UIWizardNewVM(QWidget *pParent, const QString &strMachineGroup /* = QString() */,
+UIWizardNewVM::UIWizardNewVM(QWidget *pParent, UIActionPool *pActionPool,
+                             const QString &strMachineGroup /* = QString() */,
                              const QString &strHelpHashtag /* = QString() */)
     : UINativeWizard(pParent, WizardType_NewVM, WizardMode_Auto, strHelpHashtag)
@@ -71,4 +72,5 @@
     , m_enmDiskSource(SelectedDiskSource_New)
     , m_fEmptyDiskRecommended(false)
+    , m_pActionPool(pActionPool)
 {
 #ifndef VBOX_WS_MAC
@@ -95,5 +97,5 @@
             setUnattendedPageVisible(false);
             addPage(new UIWizardNewVMHardwarePage);
-            addPage(new UIWizardNewVMDiskPage);
+            addPage(new UIWizardNewVMDiskPage(m_pActionPool));
             addPage(new UIWizardNewVMSummaryPage);
             break;
@@ -101,5 +103,5 @@
         case WizardMode_Expert:
         {
-            addPage(new UIWizardNewVMExpertPage);
+            addPage(new UIWizardNewVMExpertPage(m_pActionPool));
             break;
         }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.h	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVM.h	(revision 92413)
@@ -31,4 +31,7 @@
 #include "CMediumFormat.h"
 #include "CGuestOSType.h"
+
+/* Forward declarations: */
+class UIActionPool;
 
 enum SelectedDiskSource
@@ -71,5 +74,6 @@
 public:
 
-    UIWizardNewVM(QWidget *pParent, const QString &strMachineGroup = QString(), const QString &strHelpHashtag = QString());
+    UIWizardNewVM(QWidget *pParent, UIActionPool *pActionPool,
+                  const QString &strMachineGroup = QString(), const QString &strHelpHashtag = QString());
     bool isUnattendedEnabled() const;
     void setDefaultUnattendedInstallData(const UIUnattendedInstallData &unattendedInstallData);
@@ -241,4 +245,5 @@
        bool m_fEmptyDiskRecommended;
        QVector<KMediumVariant> m_mediumVariants;
+       UIActionPool *m_pActionPool;
     /** @} */
 };
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMDiskPage.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMDiskPage.cpp	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMDiskPage.cpp	(revision 92413)
@@ -42,5 +42,5 @@
 QUuid UIWizardNewVMDiskCommon::getWithFileOpenDialog(const QString &strOSTypeID,
                                                      const QString &strMachineFolder,
-                                                     QWidget *pCaller)
+                                                     QWidget *pCaller, UIActionPool *pActionPool)
 {
     QUuid uMediumId;
@@ -52,5 +52,5 @@
                                                          strOSTypeID,
                                                          false /* don't show/enable the create action: */,
-                                                         QUuid() /* Machinie Id */);
+                                                         QUuid() /* Machinie Id */, pActionPool);
     if (returnCode != static_cast<int>(UIMediumSelector::ReturnCode_Accepted))
         return QUuid();
@@ -58,5 +58,5 @@
 }
 
-UIWizardNewVMDiskPage::UIWizardNewVMDiskPage()
+UIWizardNewVMDiskPage::UIWizardNewVMDiskPage(UIActionPool *pActionPool)
     : m_pDiskSourceButtonGroup(0)
     , m_pDiskEmpty(0)
@@ -75,4 +75,5 @@
     , m_uMediumSizeMin(_4M)
     , m_uMediumSizeMax(uiCommon().virtualBox().GetSystemProperties().GetInfoVDSize())
+    , m_pActionPool(pActionPool)
 {
     prepare();
@@ -191,5 +192,5 @@
     QUuid uMediumId = UIWizardNewVMDiskCommon::getWithFileOpenDialog(comOSType.GetId(),
                                                                      pWizard->machineFolder(),
-                                                                     this);
+                                                                     this, m_pActionPool);
     if (!uMediumId.isNull())
     {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMDiskPage.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMDiskPage.h	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMDiskPage.h	(revision 92413)
@@ -40,4 +40,5 @@
 class QIRichTextLabel;
 class QIToolButton;
+class UIActionPool;
 class UIMediaComboBox;
 class UIMediumSizeEditor;
@@ -47,5 +48,5 @@
     QUuid getWithFileOpenDialog(const QString &strOSTypeID,
                                 const QString &strMachineFolder,
-                                QWidget *pCaller);
+                                QWidget *pCaller, UIActionPool *pActionPool);
 }
 
@@ -57,5 +58,5 @@
 public:
 
-    UIWizardNewVMDiskPage();
+    UIWizardNewVMDiskPage(UIActionPool *pActionPool);
 
 protected:
@@ -110,4 +111,5 @@
         qulonglong m_uMediumSizeMax;
     /** @} */
+    UIActionPool *m_pActionPool;
 };
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMExpertPage.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMExpertPage.cpp	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMExpertPage.cpp	(revision 92413)
@@ -41,5 +41,5 @@
 #include "CSystemProperties.h"
 
-UIWizardNewVMExpertPage::UIWizardNewVMExpertPage()
+UIWizardNewVMExpertPage::UIWizardNewVMExpertPage(UIActionPool *pActionPool)
     : m_pToolBox(0)
     , m_pDiskFormatVariantGroupBox(0)
@@ -62,4 +62,5 @@
     , m_uMediumSizeMin(_4M)
     , m_uMediumSizeMax(uiCommon().virtualBox().GetSystemProperties().GetInfoVDSize())
+    , m_pActionPool(pActionPool)
 {
     /* Create widgets: */
@@ -130,5 +131,5 @@
     QUuid uMediumId = UIWizardNewVMDiskCommon::getWithFileOpenDialog(comOSType.GetId(),
                                                                      pWizard->machineFolder(),
-                                                                     this);
+                                                                     this, m_pActionPool);
     if (!uMediumId.isNull())
     {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMExpertPage.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMExpertPage.h	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newvm/UIWizardNewVMExpertPage.h	(revision 92413)
@@ -35,4 +35,5 @@
 class QRadioButton;
 class QIToolButton;
+class UIActionPool;
 class UIAdditionalUnattendedOptions;
 class UIDiskFormatsComboBox;
@@ -53,5 +54,5 @@
 public:
 
-    UIWizardNewVMExpertPage();
+    UIWizardNewVMExpertPage(UIActionPool *pActionPool);
 
 private slots:
@@ -148,4 +149,5 @@
         qulonglong m_uMediumSizeMin;
         qulonglong m_uMediumSizeMax;
+        UIActionPool *m_pActionPool;
     /** @} */
 };

Index: /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.h	(revision 92412)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.h	(revision 92413)
@@ -34,4 +34,6 @@
 #include "CSession.h"
 
+/* Forward declarations: */
+class UIActionPool;
 
 /** UISettingsDialog extension encapsulating all the specific functionality of the Global Preferences. */
@@ -92,7 +94,8 @@
       * @param  uMachineId    Brings the machine ID.
       * @param  strCategory   Brings the name of category to be opened.
       * @param  strControl    Brings the name of control to be focused. */
     UISettingsDialogMachine(QWidget *pParent, const QUuid &uMachineId,
-                            const QString &strCategory, const QString &strControl);
+                            const QString &strCategory, const QString &strControl, UIActionPool *pActionPool);
 
 protected:
@@ -166,4 +169,5 @@
     CConsole  m_console;
 
+    UIActionPool *m_pActionPool;
 };
 
@@ -92,7 +94,8 @@
       * @param  uMachineId    Brings the machine ID.
       * @param  strCategory   Brings the name of category to be opened.
-      * @param  strControl    Brings the name of control to be focused. */
+      * @param  strControl    Brings the name of control to be focused.
+      * @param  pActionPool   Brings the action pool instance.  */
     UISettingsDialogMachine(QWidget *pParent, const QUuid &uMachineId,